| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.StorageGateway.ListTagsForResource
Description
Lists the tags that have been added to the specified resource. This operation is supported in storage gateways of all types.
This operation returns paginated results.
Synopsis
- data ListTagsForResource = ListTagsForResource' {}
- newListTagsForResource :: Text -> ListTagsForResource
- listTagsForResource_limit :: Lens' ListTagsForResource (Maybe Natural)
- listTagsForResource_marker :: Lens' ListTagsForResource (Maybe Text)
- listTagsForResource_resourceARN :: Lens' ListTagsForResource Text
- data ListTagsForResourceResponse = ListTagsForResourceResponse' {}
- newListTagsForResourceResponse :: Int -> ListTagsForResourceResponse
- listTagsForResourceResponse_marker :: Lens' ListTagsForResourceResponse (Maybe Text)
- listTagsForResourceResponse_resourceARN :: Lens' ListTagsForResourceResponse (Maybe Text)
- listTagsForResourceResponse_tags :: Lens' ListTagsForResourceResponse (Maybe [Tag])
- listTagsForResourceResponse_httpStatus :: Lens' ListTagsForResourceResponse Int
Creating a Request
data ListTagsForResource Source #
ListTagsForResourceInput
See: newListTagsForResource smart constructor.
Constructors
| ListTagsForResource' | |
Fields
| |
Instances
newListTagsForResource Source #
Arguments
| :: Text | |
| -> ListTagsForResource |
Create a value of ListTagsForResource with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:limit:ListTagsForResource', listTagsForResource_limit - Specifies that the list of tags returned be limited to the specified
number of items.
ListTagsForResource, listTagsForResource_marker - An opaque string that indicates the position at which to begin returning
the list of tags.
ListTagsForResource, listTagsForResource_resourceARN - The Amazon Resource Name (ARN) of the resource for which you want to
list tags.
Request Lenses
listTagsForResource_limit :: Lens' ListTagsForResource (Maybe Natural) Source #
Specifies that the list of tags returned be limited to the specified number of items.
listTagsForResource_marker :: Lens' ListTagsForResource (Maybe Text) Source #
An opaque string that indicates the position at which to begin returning the list of tags.
listTagsForResource_resourceARN :: Lens' ListTagsForResource Text Source #
The Amazon Resource Name (ARN) of the resource for which you want to list tags.
Destructuring the Response
data ListTagsForResourceResponse Source #
ListTagsForResourceOutput
See: newListTagsForResourceResponse smart constructor.
Constructors
| ListTagsForResourceResponse' | |
Fields
| |
Instances
newListTagsForResourceResponse Source #
Create a value of ListTagsForResourceResponse with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
ListTagsForResource, listTagsForResourceResponse_marker - An opaque string that indicates the position at which to stop returning
the list of tags.
ListTagsForResource, listTagsForResourceResponse_resourceARN - The Amazon Resource Name (ARN) of the resource for which you want to
list tags.
ListTagsForResourceResponse, listTagsForResourceResponse_tags - An array that contains the tags for the specified resource.
$sel:httpStatus:ListTagsForResourceResponse', listTagsForResourceResponse_httpStatus - The response's http status code.
Response Lenses
listTagsForResourceResponse_marker :: Lens' ListTagsForResourceResponse (Maybe Text) Source #
An opaque string that indicates the position at which to stop returning the list of tags.
listTagsForResourceResponse_resourceARN :: Lens' ListTagsForResourceResponse (Maybe Text) Source #
The Amazon Resource Name (ARN) of the resource for which you want to list tags.
listTagsForResourceResponse_tags :: Lens' ListTagsForResourceResponse (Maybe [Tag]) Source #
An array that contains the tags for the specified resource.
listTagsForResourceResponse_httpStatus :: Lens' ListTagsForResourceResponse Int Source #
The response's http status code.